Welcome to the ricecooker docs!
===============================


Quickstart
----------
Developers who are new to the ``ricecooker`` library can get started here.

.. toctree::
   :maxdepth: 1

   README <README>
   tutorial/index


   
Kolibri content platform
------------------------
The Kolibri content platform is described in the following docs, which should be
accessible to both technical and non-technical audiences.

.. toctree::
   :maxdepth: 1

   platform/README
   platform/content_types



Ricecooker API reference
------------------------
The detailed information for content developers (chef authors) is presented here:

.. toctree::
   :maxdepth: 2

   usage
   nodes
   files
   languages
   htmlapps
   exercises
   installation
   chefops


Ricecooker Utils
----------------
The ``ricecooker`` library includes a number of utilities and helper functions:

.. toctree::
   :maxdepth: 1

   parsing_html
   csv_metadata/README
   csv_metadata/csv_exercises
   csv_metadata/souschef



Ricecooker developer docs
-------------------------
To learn about the inner workings of the ``ricecooker`` library, consult the following:

.. toctree::
   :maxdepth: 1

   developer/README
   chefops
   developer/daemonization
   developer/sushops
   developer/design_cli
   developer/contributing
   developer/authors
   modules
   history

.. automodule:: ricecooker.classes



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
